**************************
***	RUN USING STATA 16 ***
**************************

* Purpose: decompose change in pass rate into test or other
* Last Updated: 06 May 2021

*------------------------------------------------------------------------------
	
	use "$output/mat_score_estimates.dta", clear
	
		egen pick = tag(yr) //retain one observation per year
		keep if pick==1
		
		keep yr ability* tot* marks_yr
		reshape long ability_ tot, i(yr) j(t)
		
		drop t
		sort yr ability_
		bysort yr : gen n = _n
		gen pct = tot/marks_yr
		
*** pooled reference, so no single base year (omitting 2017)
		gen g = .
		replace g = pct if yr==2011 & n==232
		replace g = pct if yr==2012 & n==180
		replace g = pct if yr==2013 & n==280
		replace g = pct if yr==2014 & n==320
		replace g = pct if yr==2015 & n==458
		replace g = pct if yr==2016 & n==380
		replace g = pct if yr==2018 & n==320
		replace g = pct if yr==2019 & n==156
		egen marks = mean(g)

		gen fail_us = 1 if pct < marks
		
		gen h = .
		replace h = ability_ if yr==2011 & n==232
		replace h = ability_ if yr==2012 & n==180
		replace h = ability_ if yr==2013 & n==280
		replace h = ability_ if yr==2014 & n==320
		replace h = ability_ if yr==2015 & n==458
		replace h = ability_ if yr==2016 & n==380
		replace h = ability_ if yr==2018 & n==320
		replace h = ability_ if yr==2019 & n==156
		egen level = mean(h)
	
		gen ref = 1 if ability_ < level

		collapse (count) fail_us ref, by(yr)
		
	//additional pp in failures because of diff difficulty
		gen fail_waec = .
		replace fail_waec = 231 if yr==2011
		replace fail_waec = 185 if yr==2012
		replace fail_waec = 281 if yr==2013
		replace fail_waec = 319 if yr==2014
		replace fail_waec = 457 if yr==2015
		replace fail_waec = 381 if yr==2016
		replace fail_waec = 203 if yr==2017
		replace fail_waec = 317 if yr==2018
		replace fail_waec = 135 if yr==2019
		
		gen xs_test = ref - fail_us
		gen xs_kids = (ref - fail_waec) - xs_test
		
		gen xs_test_pp = xs_test/10
		gen xs_kids_pp = xs_kids/10
		
		preserve
		//temporarily replace 2017 with missing values
		replace xs_test_pp = . if yr==2017
		replace xs_kids_pp = . if yr==2017
		//graph
		graph bar (asis) xs_test_pp xs_kids_pp, over(yr) stack ///
		ylabel(-20(5)20) ///
		legend(lab(1 "Test") lab(2 "Cohort")) ///
		subtitle("Variation in pass rates attributed to test difficulty and to the 'Cohort' (percentage points)", pos(11) span size(small)) ///
		note("Note: we separate the differences in pass rates into two parts: one can be explained by test difficulty and one" "cannot. For convenience, we refer to this latter part as 'Cohort', indicating a genuine change in cohort" "performance but we cannot, with available data, test any hypothesis about cohort competency directly." "All values are relative to an average difficulty test, based on pooled data for 2011-2019." "We cannot, with our estimates of test difficulty, provide a reasonable explanation for the sharp increase in Pass" "grades awarded in 2017; so we omit that year from this figure.", span size(small))		
		graph export "$graph\decomposition.png", replace
		restore