
**************************
***	RUN USING STATA 16 ***
**************************
	
* Purpose: graphs the trend in difficulty-adjusted performance
* Last updated: 06 May 2021

*-----------------------------------------------------------------------

//trends of educational improvement over time
	use "$input\waec_pass.dta", clear
	keep yr mat_pass mat_a_c_perc
	ren mat_pass waec_pass
	ren mat_a_c_perc waec_credit
	keep if yr > 2010
	tempfile waec
	save `waec'
	
	use "$output\mat_pass_estimates.dta", clear
	
	ren c_ us_credit
	gen us_pass = us_credit + p_
	keep yr us_pass us_credit
	
	merge 1:1 yr using `waec'
	drop _merge
	
	//gen trend, pooled benchmark (pooled values are simply average pass and credit pass rates for the 2011-19 period)
	gen trend_p = 72 + waec_pass - us_pass
	gen trend_c = 41 + waec_credit - us_credit

	line trend_p trend_c yr if yr!=2017, ///
	xlabel(2011(1)2019) ylabel(0(10)100) ///
	legend(lab(1 "Pass") lab(2 "Credit")) ///
	xtitle("") subtitle("Difficulty-adjusted performance trend (% reaching Pass and Credit levels)", pos(11) span size(small))
	graph export "$graph\dif_adj_trend.png", replace


*----------------------variance, omitting 2017

	su waec_pass if yr!=2017
	local w = r(Var)

	su trend_p if yr!=2017
	local u = r(Var)
	
	disp 1-(`u'/`w') //88% reduction
	
	
	su waec_credit if yr!=2017
	local w = r(Var)

	su trend_c if yr!=2017
	local u = r(Var)
	
	disp 1-(`u'/`w') //71% reduction

	



