**************************
***	RUN USING STATA 16 ***
**************************

* Purpose: graph WASSCE results against study findings.
* Last Updated: 06 May 2021

*---------------------------------------------------------------------------
* Graph WASSCE results against study findings
*---------------------------------------------------------------------------

	use "$input\waec_pass.dta", replace
	
	*combining WAEC and study data	
	gen src = 1
	tempfile waec
	save `waec'
	
	use "$output\mat_pass_estimates.dta", clear
	ren c_ mat_a_c_perc
	ren p_ mat_d_e_perc
	gen src = 2
	lab def src 1 "Population of WASSCE exam takers" 2 "Our sample of exam takers"
	lab values src src
	
	merge 1:1 yr src using `waec'
		
	*Bar compare waec with study	
	
	graph bar mat_a_c_perc mat_d_e_perc if yr>2010 & src==1, ///
	over(yr, gap(30)) stack blabel(total, pos(inside) format(%2.0f) color(white)) ///
	legend(lab(1 "Credit or better") lab(2 "Pass") order(2 1) col(2)) ///
	subtitle("{bf:Population of WASSCE exam takers}", span pos(11)) ///
	ylabel(20 "20%" 40 "40%" 60 "60%" 80 "80%") ysc(r(0 87)) ///
	name(wassce, replace) nodraw

	graph bar mat_a_c_perc mat_d_e_perc if yr>2010 & src==2, ///
	over(yr, gap(30)) stack blabel(total, pos(inside) format(%2.0f) color(white)) ///
	legend(lab(1 "Credit or better") lab(2 "Pass") order(2 1) col(2)) ///
	subtitle("{bf:Our sample of exam takers}", span pos(11)) ///
	ylabel(20 "20%" 40 "40%" 60 "60%" 80 "80%") ysc(r(0 87)) ///
	name(study, replace) nodraw
	
	grc1leg wassce study, ///
	note("Note: Credit or better = WASSCE grades A1-C6; Pass = WASSCE grades D7-E8", span size(vsmall) color(gray))
	graph export "$graph\waec_iepa_compare.png", replace

	
	
	
